@@ -213,6 +213,164 @@ constants &Sys::Virt::Domain::STATE_*.
 
 =back
 
+=item my ($state, $reason) = $dom->get_state()
+
+Returns an array whose values specify the current state
+of the guest, and the reason for it being in that state.
+The C<$state> values are the same as for the C<get_info>
+API, and the C<$reason> values come from:
+
+=over 4
+
+=item Sys::Virt::Domain::STATE_CRASHED_UNKNOWN
+
+It is not known why the domain has crashed
+
+=item Sys::Virt::Domain::STATE_NOSTATE_UNKNOWN
+
+It is not known why the domain has no state
+
+=item Sys::Virt::Domain::STATE_PAUSED_DUMP
+
+The guest is paused due to a core dump operation
+
+=item Sys::Virt::Domain::STATE_PAUSED_FROM_SNAPSHOT
+
+The guest is paused due to a snapshot
+
+=item Sys::Virt::Domain::STATE_PAUSED_IOERROR
+
+The guest is paused due to an I/O error
+
+=item Sys::Virt::Domain::STATE_PAUSED_MIGRATION
+
+The guest is paused due to migration
+
+=item Sys::Virt::Domain::STATE_PAUSED_SAVE
+
+The guest is paused due to a save operation
+
+=item Sys::Virt::Domain::STATE_PAUSED_UNKNOWN
+
+It is not known why the domain has paused
+
+=item Sys::Virt::Domain::STATE_PAUSED_USER
+
+The guest is paused at admin request
+
+=item Sys::Virt::Domain::STATE_PAUSED_WATCHDOG
+
+The guest is paused due to the watchdog
+
+=item Sys::Virt::Domain::STATE_RUNNING_BOOTED
+
+The guest is running after being booted
+
+=item Sys::Virt::Domain::STATE_RUNNING_FROM_SNAPSHOT
+
+The guest is running after restore from snapshot
+
+=item Sys::Virt::Domain::STATE_RUNNING_MIGRATED
+
+The guest is running after migration
+
+=item Sys::Virt::Domain::STATE_RUNNING_MIGRATION_CANCELED
+
+The guest is running after migration abort
+
+=item Sys::Virt::Domain::STATE_RUNNING_RESTORED
+
+The guest is running after restore from file
+
+=item Sys::Virt::Domain::STATE_RUNNING_SAVE_CANCELED
+
+The guest is running after save cancel
+
+=item Sys::Virt::Domain::STATE_RUNNING_UNKNOWN
+
+It is not known why the domain has started
+
+=item Sys::Virt::Domain::STATE_RUNNING_UNPAUSED
+
+The guest is running after a resume
+
+=item Sys::Virt::Domain::STATE_SHUTDOWN_UNKNOWN
+
+It is not known why the domain has shutdown
+
+=item Sys::Virt::Domain::STATE_SHUTDOWN_USER
+
+The guest is shutdown due to admin request
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_CRASHED
+
+The guest is shutoff after a crash
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_DESTROYED
+
+The guest is shutoff after being destroyed
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_FAILED
+
+The guest is shutoff due to a virtualization failure
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_FROM_SNAPSHOT
+
+The guest is shutoff after a snapshot
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_MIGRATED
+
+The guest is shutoff after migration
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_SAVED
+
+The guest is shutoff after a save
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_SHUTDOWN
+
+The guest is shutoff due to controlled shutdown
+
+=item Sys::Virt::Domain::STATE_SHUTOFF_UNKNOWN
+
+It is not known why the domain has shutoff
+
+=back
+
+=item my $info = $dom->get_control_info($flags=0)
+
+Returns a hash reference providing information about
+the control channel. The returned keys in the hash
+are
+
+=over 4
+
+=item C<state>
+
+One of the CONTROL INFO constants listed later
+
+=item C<details>
+
+Currently unsed, always 0.
+
+=item C<stateTime>
+
+The elapsed time since the control channel entered
+the current state.
+
+=back
+
+=item $dom->send_key($keycodeset, $holdtime, \@keycodes, $flags=0)
+
+Sends a sequence of keycodes to the guest domain. The
+C<$keycodeset> should be one of the constants listed
+later in the KEYCODE SET section. C<$holdtiem> is the
+duration, in milliseconds, to keep the key pressed
+before releasing it and sending the next keycode.
+C<@keycodes> is an array reference containing the list
+of keycodes to send to the guest. The elements in the
+array should be keycode values from the specified
+keycode set. C<$flags> is currently unused.
+
 =item my $info = $dom->get_block_info($dev, $flags=0)
 
 Returns a hash reference summarising the disk usage of
@@ -504,6 +662,11 @@ will be performed. The C<flags>, C<dname>, C<uri> and C<bandwidth>
 parameters are all optional, and if omitted default to zero, C<undef>,
 C<undef>, and zero respectively.
 
+=item $ddom = $dom->migrate2(destcon, dxml, flags, dname, uri, bandwidth)
+
+Migrate a domain to an alternative host. This function works in the
+same way as C<migrate>, except is also allows C<dxml> to specify a
+changed XML configuration for the guest on the target host.
 
 =item $dom->migrate_to_uri(desturi, flags, dname, bandwidth)
 
@@ -523,6 +686,15 @@ will be performed. The C<flags>, C<dname> and C<bandwidth>
 parameters are all optional, and if omitted default to zero, C<undef>,
 C<undef>, and zero respectively.
 
+=item $dom->migrate_to_uri2(dconnuri, miguri, dxml, flags, dname, bandwidth)
+
+Migrate a domain to an alternative host. This function works in almost
+the same way as C<migrate_to_uri>, except is also allows C<dxml> to
+specify a changed XML configuration for the guest on the target host.
+The C<dconnuri> must always specify the URI of the remote libvirtd
+daemon, or be C<undef>. The C<miguri> parameter can be used to specify
+the URI for initiating the migration operation, or be C<undef>.
+
 
 =item $dom->migrate_set_max_downtime($downtime, $flags)
 
@@ -538,6 +710,19 @@ Set the maximum allowed bandwidth during migration of the guest.
 The C<bandwidth> parameter is measured in kilobytes/second.
 The C<$flags> parameter is currently unused and defaults to zero.
 
+=item $dom->inject_nmi($flags)
+
+Trigger an NMI in the guest virtual machine. The C<$flags> parameter
+is currently unused and defaults to 0.
+
+=item $dom->screenshot($st, $screen, $flags)
+
+Capture a screenshot of the virtual machine's monitor. The C<$screen>
+parameter controls which monitor is captured when using a multi-head
+or multi-card configuration. C<$st> must be a C<Sys::Virt::Stream>
+object from which the data can be read. C<$flags> is currently unused
+and defaults to 0.
+
 =item @vcpuinfo = $dom->get_vcpu_info()
 
 Obtain information about the state of all virtual CPUs in a running
@@ -715,6 +900,31 @@ The domain is inactive, and crashed.
 =back
 
 
+=head2 CONTROL INFO
+
+The following constants can be used to determine what the
+guest domain control channel status is
+
+=over 4
+
+=item Sys::Virt::Domain::CONTROL_ERROR
+
+The control channel has a fatal error
+
+=item Sys::Virt::Domain::CONTROL_OK
+
+The control channel is ready for jobs
+
+=item Sys::Virt::Domain::CONTROL_OCCUPIED
+
+The control channel is busy
+
+=item Sys::Virt::Domain::CONTROL_JOB
+
+The control channel is busy with a job
+
+=back
+
 =head2 DOMAIN CREATION
 
 The following constants can be used to control the behaviour
@@ -726,9 +936,42 @@ of domain creation
 
 Keep the guest vCPUs paused after starting the guest
 
+=item Sys::Virt::Domain::START_AUTODESTROY
+
+Automatically destroy the guest when the connection is closed (or fails)
+
 =back
 
 
+=head2 KEYCODE SETS
+
+The following constants define the set of supported keycode
+sets
+
+=over 4
+
+=item Sys::Virt::Domain::KEYCODE_SET_LINUX
+
+The Linux event subsystem keycodes
+
+=item Sys::Virt::Domain::KEYCODE_SET_XT
+
+The original XT keycodes
+
+=item Sys::Virt::Domain::KEYCODE_SET_ATSET1
+
+The AT Set1 keycodes (aka XT)
+
+=item Sys::Virt::Domain::KEYCODE_SET_ATSET2
+
+The AT Set2 keycodes (aka AT)
+
+=item Sys::Virt::Domain::KEYCODE_SET_ATSET3
+
+The AT Set3 keycodes (aka PS2)
+
+=back
+
 =head2 MEMORY PEEK
 
 The following constants can be used with the C<memory_peek>
@@ -812,6 +1055,10 @@ operations
 
 =over 4
 
+=item Sys::Virt::Domain::MEM_CURRENT
+
+Modify the current state
+
 =item Sys::Virt::Domain::MEM_LIVE
 
 Modify only the live state of the domain
@@ -820,6 +1067,31 @@ Modify only the live state of the domain
 
 Modify only the persistent config of the domain
 
+=item Sys::Virt::Domain::MEM_MAXIMUM
+
+Modify the maximum memory value
+
+=back
+
+=head2 CONFIG OPTIONS
+
+The following constants are used to control what configuration
+a domain update changes
+
+=over 4
+
+=item Sys::Virt::Domain::AFFECT_CURRENT
+
+Modify the current state
+
+=item Sys::Virt::Domain::AFFECT_LIVE
+
+Modify only the live state of the domain
+
+=item Sys::Virt::Domain::AFFECT_CONFIG
+
+Modify only the persistent config of the domain
+
 =back
 
 =head2 MIGRATE OPTIONS
@@ -1114,6 +1386,10 @@ Graphics client connections.
 
 File IO errors, typically from disks, with a root cause
 
+=item Sys::Virt::Domain::EVENT_ID_CONTROL_ERROR
+
+Errors from the virtualization control channel
+
 =back
 
 =head2 IO ERROR EVENT CONSTANTS
